function signal = TradingStrategy(start,finish)



%   function signal = TradingStrategy(start,finish)
%
%
%   subroutine called by BGJ_Table2.m
%   Input arguments are the "start" and "finish" of the trading period.
%   Output "signal" is a structure containing key information:
%
%   "signal" will be an Nx7 array with columns:
%       col 1   mthnum
%       col 2   yyyy
%       col 3   mm
%       col 4   excess market return
%       col 5   RF
%       col 6   0/1 signal for investment in tbill (equities)
%       col 7   excess return on managed portfolio
%
%
%
%
%
%   PG: 4 Feb-2019



global data



signal.vw=nan(finish-start+1,7);            % to store trading signal from predictive regressions
signal.ew=signal.vw;


for t=start:finish                          % cycle monthly thru from 1954:4 to 1986:12

    I=data(:,1)>=t-36 & data(:,1)<=t-1;     % rolling 36-month estimation window
    window=data(I,:);

    y=window(:,9);                          % VW mkt return (excess)
    x=[ones(length(y),1) window(:,8)];      % independent variable
    beta.vw=(x'*x)\(x'*y);                  % estimate regression parameters
    
    y=window(:,10);                         % EW mkt return (excess)
    x=[ones(length(y),1) window(:,8)];      % same independent var as above
    beta.ew=(x'*x)\(x'*y);
    
    
    I=data(:,1)==t;                         % predict 1-month ahead excess return
    yhat.vw=beta.vw'*[1 data(I,8)]';        % nb: BGJ name their dependent variable "xhat"
    yhat.ew=beta.ew'*[1 data(I,8)]';        % I'll use the more conventional "yhat".

    
%   the "signal" structure allows compilation of Table 2 summary stats
%   "signal" is also used for the market-timing tests in Table 4

    signal.vw(t-start+1,1:3)=data(I,1:3);   % record mthnum, YYYY, MM
    signal.vw(t-start+1,4:5)=data(I,[9 8]); % record VW-RF, RF
    
    if yhat.vw>0                            % if model predicts up market
        signal.vw(t-start+1,6:7)=[1 data(I,9)]; % "1" signals invest in equities
        
    else                                    % invest in Tbill, hence excess return is zero
        signal.vw(t-start+1,6:7)=[0 0];         % "0" signals invest in Tbill
        
    end
    

    
    signal.ew(t-start+1,1:3)=data(I,1:3);   % record mthnum, YYYY, MM
    signal.ew(t-start+1,4:5)=data(I,[10 8]);% record EW-RF, RF  
    
    if yhat.ew>0                            % if model predicts up market
        signal.ew(t-start+1,6:7)=[1 data(I,10)];% "1" signals invest in equities
        
    else                                    % invest in Tbill, hence excess return is zero
        signal.ew(t-start+1,6:7)=[0 0];         % "0" signals invest in Tbill
    end
    
end                                         % go to next month "t"





