function signal = TradingStrategy_placebo(start,finish)



%   function signal = TradingStrategy_placebo(start,finish)
%
%
%   subroutine called by PlaceboData_AllKeyResults.m
%   Input arguments are the "start" and "finish" of the trading period.
%   Output "signal" is a structure containing key information:
%
%   "signal" will be an Nx7 array with columns:
%       col 1   mthnum
%       col 2   yyyy
%       col 3   mm
%       col 4   excess market return
%       col 5   RF
%       col 6   0/1 signal for investment in tbill (equities)
%       col 7   excess return on managed portfolio
%
%
%
%
%
%   PG:  4 Feb-2019
%   TH: 25 Feb-2019: amending original code for global analysis
%   TH:  7 Apr-2019: amending code to handle placebo dataset


%%  construct "signal" data structure ready for use back in calling program


global data



signal=nan(finish-start+1,7);              % to store trading signal from predictive regressions


for t=start:finish                          % cycle monthly

    I=data(:,1)>=t-36 & data(:,1)<=t-1;     % rolling 36-month estimation window
    window=data(I,:);

    y=window(:,6);                          % mkt return (excess)
    x=[ones(length(y),1) window(:,5)];      % independent variable
    beta=(x'*x)\(x'*y);                     % estimate regression parameters
    
    I=data(:,1)==t;                         % predict 1-month ahead excess return
    yhat=beta'*[1 data(I,5)]';              % nb: BGJ name their dependent variable "xhat"
    
%   the "signal" structure allows compilation of Table 2 summary stats
%   "signal" is also used for the market-timing tests in Table 4

    signal(t-start+1,1:3)=data(I,1:3);      % record mthnum, YYYY, MM
    signal(t-start+1,4:5)=data(I,[6 5]);    % record RM-RF, RF
    
    if yhat>0                               % if model predicts up market
        signal(t-start+1,6:7)=[1 data(I,6)];% "1" signals invest in equities
        
    else                                    % invest in Tbill, hence excess return is zero
        signal(t-start+1,6:7)=[0 0];        % "0" signals invest in Tbill
        
    end
    
end                                         % go to next month "t"


